==> schlix-cms-v2.1.8-7.zip: schlix/system/macros/frontendeditcontrol/frontendeditcontrol-doc.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC, Inc.
// http://www.schlix.com
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

global $HTMLHeader;

try
{
    $obj_class = get_class($caller_object);
    $obj_admin_class = $obj_class.'_Admin';
    $obj_admin_class_instance = new $obj_admin_class();
    
    $obj_display_class = str_replace('App\\','', $obj_class);
    $app_description = $caller_object->getApplicationDescription();
    $app_display = (strtolower($obj_display_class) != strtolower($app_description)) ? $app_description.' ('.$obj_display_class.')' : $app_description;
    $edit_main_id = $data[$edit_pk];
    $link = $obj_admin_class_instance->createFriendlyAdminURL("action={$edit_action}&id={$edit_main_id}");
}
catch (Exception $exc)
{
    return false;
}
?>
<div class="row frontendeditcontrol-doc-container">
    <!-- col -->
    <div class="col-sm-10">
        <i class="<?= $edit_icon ?>"></i>&nbsp;<?= $app_display ?>,&nbsp;<?= ___('ID') ?>: <?= $edit_main_id ?>, <?= ___('GUID') ?>: <?= $data['guid']?>, <?= ___('version') ?>: <?= $data['version'] ?><br />
        <i class="fas fa-calendar-alt"></i>&nbsp;<?= ___('Created') ?>: <?= $data['date_created']?><br />
        <i class="fas fa-calendar-alt"></i>&nbsp;<?= ___('Last Updated') ?>: <?= $data['date_modified']?>
    </div>
    <!-- col -->
    <div class="col-sm-2 text-right"><a class="frontendeditcontrol-button" target="_blank" href="<?= $link ?>"><i class="fas fa-pencil-alt"></i> <?= ___('Edit') ?></a></div>
    <!-- end col -->
</div>

<div style="clear:both"></div>

==> schlix-cms-v2.2.2-1.zip: schlix/system/macros/frontendeditcontrol/frontendeditcontrol-doc.template.php <==
<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
// SCHLIX WEB CONTENT MANAGEMENT SYSTEM - Copyright (C) SCHLIX WEB INC, Inc.
// http://www.schlix.com
// This is a SHARED SOURCE
// You may use this software commercially, but you are not allowed to create a fork or create a derivative of this software
// Please read the license for details
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

global $HTMLHeader;

try
{
    $obj_class = get_class($caller_object);
    $obj_admin_class = $obj_class.'_Admin';
    $obj_admin_class_instance = new $obj_admin_class();
    
    $obj_display_class = str_replace('App\\','', $obj_class);
    $app_description = $caller_object->getApplicationDescription();
    $app_display = (strtolower($obj_display_class) != strtolower($app_description)) ? $app_description.' ('.$obj_display_class.')' : $app_description;
    $edit_main_id = $data[$edit_pk];
    $link = $obj_admin_class_instance->createFriendlyAdminURL("action={$edit_action}&id={$edit_main_id}");
}
catch (Exception $exc)
{
    return false;
}
?>
<x-ui:row class="frontendeditcontrol-doc-container">
    <!-- col -->
    <x-ui:column xs="9">
        <i class="<?= $edit_icon ?>"></i>&nbsp;<?= $app_display ?>,&nbsp;<?= ___('ID') ?>: <?= $edit_main_id ?>, <?= ___('GUID') ?>: <?= $data['guid']?>, <?= ___('version') ?>: <?= $data['version'] ?><br />
        <i class="fas fa-calendar-alt"></i>&nbsp;<?= ___('Created') ?>: <?= $data['date_created']?><br />
        <i class="fas fa-calendar-alt"></i>&nbsp;<?= ___('Last Updated') ?>: <?= $data['date_modified']?>
    </x-ui:column>
    <!-- col -->
    <x-ui:column xs="3" class="text-right"><a class="frontendeditcontrol-button" target="_blank" href="<?= $link ?>"><i class="fas fa-pencil-alt"></i> <?= ___('Edit') ?></a></x-ui:column>
    <!-- end col -->
</x-ui:row>

<x-ui:clearboth />
